@@ -17,6 +17,8 @@ import cannerflow.workspace
 import cannerflow.constants
 import cannerflow.exceptions
 import cannerflow.utils
+import nest_asyncio
+nest_asyncio.apply()
 
 __all__ = ["bootstrap", "Client"]
 
